Learn R Programming

sincell (version 1.4.2)

pseudoreplicatesbynoise: Auxiliary function of sc_InSilicoCellsReplicatesObj function used when its parameter method="variance.deciles"

Description

Auxiliary function implemented in C++ making part of the sc_InSilicoCellsReplicatesObj function when its parameter method="variance.deciles".

Usage

pseudoreplicatesbynoise(originaldata, rows, colums, deciles, 
  lengthdeciles, coorsorted, vargenessorted, positive, seed)

Arguments

originaldata
"expressionmatrix" within Sincell object: numeric matrix containing a gene expression matrix gathering the expression levels of each single-cell in the experiment (displayed by columns) for each detected gene (displayed by rows)
rows
number of rows in list "expressionmatrix" within Sincell object
colums
number of colums in list "expressionmatrix" within Sincell object
deciles
array containing the indexes indicating the limits of the deciles based on mean of gene expression
lengthdeciles
length(deciles)
coorsorted
order of permutated indexes
vargenessorted
Vector containing for each gene in "expressionmatrix" the variance of the expression levels. Order of genes corresponds to mean expression levels (increasing order)
positive
Force the new matrix to be positive. 1 for TRUE, 0 for FALSE
seed
seed integer for random generation

Value

  • A numeric matrix is returned as described in sc_InSilicoCellsReplicatesObj when method="variance.deciles"

See Also

sc_InSilicoCellsReplicatesObj()